gvr_buffer_viewport_equal

Function gvr_buffer_viewport_equal 

pub unsafe extern "C" fn gvr_buffer_viewport_equal(
    a: *const gvr_buffer_viewport,
    b: *const gvr_buffer_viewport,
) -> bool
Compares two gvr_buffer_viewport instances and returns true if they specify the same view mapping.

@param a Instance of a buffer viewport. @param b Another instance of a buffer viewport. @return True if the passed viewports are the same.