gvr_controller_state_get_api_status

Function gvr_controller_state_get_api_status 

pub unsafe extern "C" fn gvr_controller_state_get_api_status(
    state: *const gvr_controller_state,
) -> i32
Gets the API status of the controller state. Returns one of the gvr_controller_api_status variants, but returned as an int32_t for ABI compatibility.

@param state The controller state to get the status from. @return The status code from the controller state, as a gvr_controller_api_status variant.