pub type gvr_controller_context = gvr_controller_context_;Expand description
Represents a Daydream Controller API object, used to invoke the Daydream Controller API.
Aliased Type
pub struct gvr_controller_context { /* private fields */ }pub type gvr_controller_context = gvr_controller_context_;Represents a Daydream Controller API object, used to invoke the Daydream Controller API.
pub struct gvr_controller_context { /* private fields */ }